@@ -17,6 +17,7 @@
 #   Alessandro Amici - B-Open - https://bopen.eu
 #
 
+import os
 import functools
 import logging
 import pkgutil
@@ -34,15 +35,6 @@ ffi.cdef(
 )
 
 
-class RaiseOnAttributeAccess(object):
-    def __init__(self, exc, message):
-        self.message = message
-        self.exc = exc
-
-    def __getattr__(self, attr):
-        raise RuntimeError(self.message) from self.exc
-
-
 LIBNAMES = ["eccodes", "libeccodes.so", "libeccodes"]
 
 try:
@@ -51,15 +43,18 @@ try:
 except Exception:
     pass
 
+if os.environ.get("ECCODES_DIR"):
+    eccdir = os.environ["ECCODES_DIR"]
+    LIBNAMES.insert(0, os.path.join(eccdir, "lib/libeccodes.so"))
+    LIBNAMES.insert(0, os.path.join(eccdir, "lib64/libeccodes.so"))
+
 for libname in LIBNAMES:
     try:
         lib = ffi.dlopen(libname)
-        LOG.info("ecCodes library found using name '%s'.", libname)
+        LOG.debug("ecCodes library found using name '%s'.", libname)
         break
-    except OSError as exc:
-        # lazy exception
-        lib = RaiseOnAttributeAccess(exc, 'ecCodes library not found on the system.')
-        LOG.info("ecCodes library not found using name '%s'.", libname)
+    except OSError:
+        raise RuntimeError(f"ecCodes library not found using {LIBNAMES}")
 
 
 # default encoding for ecCodes strings
@@ -551,6 +546,11 @@ def codes_grib_multi_support_off(context=None):
     lib.codes_grib_multi_support_off(context)
 
 
+def codes_grib_multi_support_reset_file(file):
+    context = lib.codes_context_get_default()
+    return lib.codes_grib_multi_support_reset_file(context, file)
+
+
 def codes_write(handle, outfile):
     # type: (cffi.FFI.CData, T.BinaryIO) -> None
     """
