@@ -35,8 +35,13 @@ try:
         import eccodes
     else:
         from . import bindings as eccodes
-except RuntimeError:
-    import pyeccodes.compat as eccodes
+except RuntimeError as exc:
+    # hide the pyeccodes import error from the majority of the users
+    # that have problems with the ecCodes bindings
+    try:
+        import pyeccodes.compat as eccodes
+    except ImportError:
+        raise exc
 
 eccodes_version = eccodes.codes_get_api_version()
 
@@ -58,8 +63,7 @@ def multi_enabled(file):
     #
     # @alexamici: I'm note sure this is thread-safe. See :#141
     #
-    context = eccodes.lib.codes_context_get_default()
-    eccodes.lib.codes_grib_multi_support_reset_file(context, file)
+    eccodes.codes_grib_multi_support_reset_file(file)
     try:
         yield
     except Exception:
