@@ -1,5 +1,6 @@
 import os.path
 
+import numpy as np
 import pytest
 
 from cfgrib import messages
@@ -16,7 +17,7 @@ def test_Message_read():
     assert res1.message_get('paramId') == 129
     assert res1['paramId'] == 129
     assert list(res1)[0] == 'globalDomain'
-    assert list(res1.message_iterkeys('time'))[0] == 'dataDate'
+    assert list(res1.message_grib_keys('time'))[0] == 'dataDate'
     assert 'paramId' in res1
     assert len(res1) > 100
 
@@ -26,7 +27,12 @@ def test_Message_read():
     assert res1.message_get('non-existent-key', default=1) == 1
 
     res2 = messages.Message.from_message(res1)
-    assert res2.items() == res1.items()
+    for (k2, v2), (k1, v1) in zip(res2.items(), res1.items()):
+        assert k2 == k1
+        if isinstance(v2, np.ndarray) or isinstance(v1, np.ndarray):
+            assert np.allclose(v2, v1)
+        else:
+            assert v2 == v1
 
     with open(TEST_DATA) as file:
         with pytest.raises(EOFError):
@@ -48,7 +54,7 @@ def test_Message_write(tmpdir):
     assert res['gridType'] == 'reduced_gg'
 
     res['pl'] = [2.0, 3.0]
-    assert res['pl'] == [2.0, 3.0]
+    assert np.allclose(res['pl'], [2.0, 3.0])
 
     # warn on errors
     res['centreDescription'] = 'DUMMY'
