@@ -9,6 +9,7 @@ from cfgrib import dataset
 
 SAMPLE_DATA_FOLDER = os.path.join(os.path.dirname(__file__), 'sample-data')
 TEST_DATA = os.path.join(SAMPLE_DATA_FOLDER, 'era5-levels-members.grib')
+TEST_DATA_UKMO = os.path.join(SAMPLE_DATA_FOLDER, 'forecast_monthly_ukmo.grib')
 
 
 def test_enforce_unique_attributes():
@@ -89,6 +90,45 @@ def test_build_data_var_components_encode_cf_geography():
     assert data_var.data[:, :, :, :, :, :].mean() > 0.0
 
 
+def test_build_dataset_components_time_dims():
+    index_keys = sorted(dataset.ALL_KEYS)
+    index = dataset.open_fileindex(TEST_DATA_UKMO, 'warn', '{path}.{short_hash}.idx', index_keys)
+    dims = dataset.build_dataset_components(index, read_keys=[])[0]
+    assert dims == {
+        'latitude': 6,
+        'longitude': 11,
+        'number': 28,
+        'step': 20,
+        'time': 8,
+    }
+
+    index_keys = sorted(dataset.ALL_KEYS)
+    index = dataset.open_fileindex(TEST_DATA_UKMO, 'warn', '{path}.{short_hash}.idx', index_keys)
+    dims, *_ = dataset.build_dataset_components(
+        index, read_keys=[], time_dims=('indexing_time', 'verifying_time')
+    )
+    assert dims == {
+        'number': 28,
+        'indexing_time': 2,
+        'verifying_time': 4,
+        'latitude': 6,
+        'longitude': 11
+    }
+
+    index_keys = sorted(dataset.ALL_KEYS)
+    index = dataset.open_fileindex(TEST_DATA_UKMO, 'warn', '{path}.{short_hash}.idx', index_keys)
+    dims, *_ = dataset.build_dataset_components(
+        index, read_keys=[], time_dims=('indexing_time', 'step')
+    )
+    assert dims == {
+        'number': 28,
+        'indexing_time': 2,
+        'step': 20,
+        'latitude': 6,
+        'longitude': 11
+    }
+
+
 def test_Dataset():
     res = dataset.open_file(TEST_DATA)
     assert 'Conventions' in res.attributes
