@@ -1,12 +1,9 @@
-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import os.path
 
 import pytest
+
 xr = pytest.importorskip('xarray')  # noqa
 
-from cfgrib import eccodes
 from cfgrib import xarray_store
 
 
@@ -25,21 +22,22 @@ def test_open_dataset():
     var = res['t']
     assert var.attrs['GRIB_gridType'] == 'regular_ll'
     assert var.attrs['units'] == 'K'
-    assert var.dims == \
-        ('number', 'time', 'isobaricInhPa', 'latitude', 'longitude')
+    assert var.dims == ('number', 'time', 'isobaricInhPa', 'latitude', 'longitude')
 
-    assert var.mean() > 0.
+    assert var.mean() > 0.0
 
     with pytest.raises(ValueError):
         xarray_store.open_dataset(TEST_DATA, engine='netcdf4')
 
-    with pytest.raises(ValueError):
-        xarray_store.open_dataset(TEST_IGNORE)
+    res = xarray_store.open_dataset(TEST_IGNORE, backend_kwargs={'errors': 'warn'})
+    assert 'isobaricInhPa' in res.dims
 
     res = xarray_store.open_dataset(TEST_IGNORE, backend_kwargs={'errors': 'ignore'})
-
     assert 'isobaricInhPa' in res.dims
 
+    with pytest.raises(ValueError):
+        xarray_store.open_dataset(TEST_IGNORE, backend_kwargs={'errors': 'raise'})
+
 
 def test_open_dataset_corrupted():
     res = xarray_store.open_dataset(TEST_CORRUPTED)
@@ -47,8 +45,8 @@ def test_open_dataset_corrupted():
     assert res.attrs['GRIB_edition'] == 1
     assert len(res.data_vars) == 1
 
-    with pytest.raises(eccodes.EcCodesError):
-        xarray_store.open_dataset(TEST_CORRUPTED, backend_kwargs={'grib_errors': 'strict'})
+    with pytest.raises(Exception):
+        xarray_store.open_dataset(TEST_CORRUPTED, backend_kwargs={'grib_errors': 'raise'})
 
 
 def test_open_dataset_encode_cf_time():
@@ -60,7 +58,7 @@ def test_open_dataset_encode_cf_time():
     assert res['t'].attrs['GRIB_units'] == 'K'
     assert res['t'].dims == ('number', 'time', 'level', 'values')
 
-    assert res['t'].mean() > 0.
+    assert res['t'].mean() > 0.0
 
 
 def test_open_dataset_encode_cf_vertical():
@@ -70,7 +68,7 @@ def test_open_dataset_encode_cf_vertical():
     var = res['t']
     assert var.dims == ('number', 'dataDate', 'dataTime', 'isobaricInhPa', 'values')
 
-    assert var.mean() > 0.
+    assert var.mean() > 0.0
 
 
 def test_open_dataset_encode_cf_geography():
@@ -84,7 +82,7 @@ def test_open_dataset_encode_cf_geography():
     assert var.attrs['GRIB_units'] == 'K'
     assert var.dims == ('number', 'dataDate', 'dataTime', 'level', 'latitude', 'longitude')
 
-    assert var.mean() > 0.
+    assert var.mean() > 0.0
 
 
 def test_open_dataset_eccodes():
@@ -97,11 +95,11 @@ def test_open_dataset_eccodes():
     assert var.attrs['units'] == 'K'
     assert var.dims == ('number', 'time', 'isobaricInhPa', 'latitude', 'longitude')
 
-    assert var.mean() > 0.
+    assert var.mean() > 0.0
 
 
 def test_open_datasets():
     res = xarray_store.open_datasets(TEST_DATASETS)
 
     assert len(res) > 1
-    assert res[0].attrs['GRIB_edition'] == 1
+    assert res[0].attrs['GRIB_centre'] == 'ecmf'
